@@ -1,4 +1,4 @@
-/*  $Id: command.c 2338 2006-01-01 23:31:02Z rra $
+/*  $Id: command.c 2588 2006-06-13 20:54:44Z rra $
 **
 **  Shared command handling for k4start and k5start.
 **
@@ -20,30 +20,23 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+/* Global so that it can be used in signal handlers. */
+static pid_t global_child_pid;
+
+
 /*
-**  Run the given aklog command, returning its exit status or 7 if it could
-**  not be executed.  The command must be a fully-qualified path.
+**  Run the given aklog command, returning its exit status.  The command must
+**  be a fully-qualified path.
 */
 int
 run_aklog(const char *aklog, int verbose)
 {
     int status;
 
-    if (access(aklog, X_OK) == 0) {
-        status = system(aklog);
-
-        /* IRIX 6.5's WEXITSTATUS() macro is broken and can't cope with being
-           called directly on the return value of system().  If we can't
-           execute the aklog program, set the exit status to an arbitrary but
-           distinct value. */
-        status = WEXITSTATUS(status);
-        if (verbose)
-            printf("%s exited with status %d\n", aklog, status);
-    } else {
-        if (verbose)
-            printf("no execute access to %s\n", aklog);
-        status = 7;
-    }
+    status = system(aklog);
+    status = WEXITSTATUS(status);
+    if (verbose)
+        printf("%s exited with status %d\n", aklog, status);
     return status;
 }
 
@@ -60,25 +53,48 @@ child_handler(int signal)
 }
 
 
+/*
+**  This handler is installed for signals that should be propagated to the
+**  child (and ignored by kstart).
+*/
+static void
+propagate_handler(int signal)
+{
+    kill(global_child_pid, signal);
+}
+
+
 /*
 **  Start a command, returning its PID.  Takes the command to run, which will
 **  be searched for on the path if not fully-qualified, and then the arguments
 **  to pass to it.  If execution fails for some reason, returns -1.
+**
+**  This function should only be called once before a call to finish_command;
+**  otherwise, the signal handler code won't work properly.
 */
 pid_t
 start_command(const char *command, char **argv)
 {
     pid_t child;
 
+    /* Ignored. */
     signal(SIGCHLD, child_handler);
+
+    /* Propagated to child process. */
+    signal(SIGHUP, propagate_handler);
+    signal(SIGTERM, propagate_handler);
+    signal(SIGQUIT, propagate_handler);
+
     child = fork();
     if (child < 0)
         return -1;
     else if (child == 0) {
         execvp(command, argv);
         return -1;
-    } else
+    } else {
+        global_child_pid = child;
         return child;
+    }
 }
 
 
