@@ -1,5 +1,5 @@
 /* command.h -- Shared command execution for k4start and k5start. */
-/* $Id: command.h 109 2005-04-25 05:27:33Z eagle $ */
+/* $Id: command.h 2588 2006-06-13 20:54:44Z rra $ */
 
 #ifndef COMMAND_H
 #define COMMAND_H 1
@@ -11,7 +11,9 @@
 int run_aklog(const char *aklog, int verbose);
 
 /* Start a command, executing the given command with the given argument vector
-   (which includes argv[0]).  Returns the PID or -1 on error. */
+   (which includes argv[0]).  Returns the PID or -1 on error.  This function
+   should not be called again without an intervening finish_command or the
+   signal handling won't work properly. */
 pid_t start_command(const char *command, char **argv);
 
 /* Check to see if the given command has finished.  If so, return 1 and set
