@@ -1,4 +1,4 @@
-/*  $Id: k5start.c 2553 2006-05-06 05:12:32Z rra $
+/*  $Id: k5start.c 2597 2006-06-24 02:39:40Z rra $
 **
 **  Kerberos v5 kinit replacement suitable for daemon authentication.
 **
@@ -50,11 +50,13 @@
 # if HAVE_KAFS_H
 #  include <kafs.h>
 # endif
-# define lsetpag() k_setpag()
 #elif HAVE_LSETPAG
 int lsetpag(void);
+# define k_hasafs() (1)
+# define k_setpag() lsetpag()
 #else
-# define lsetpag() (0)
+# define k_hasafs() (1)
+# define k_setpag() (0)
 #endif
 
 /* __attribute__ is available in gcc 2.5 and later, but only with gcc 2.7
@@ -619,9 +621,14 @@ main(int argc, char *argv[])
 
     /* If built with setpag support and we're running a command, create the
        new PAG now before the first authentication. */
-    if (command != NULL && options.run_aklog)
-        if (lsetpag() < 0)
-            die("unable to create PAG: %s", strerror(errno));
+    if (command != NULL && options.run_aklog) {
+        if (k_hasafs()) {
+            if (k_setpag() < 0)
+                die("unable to create PAG: %s", strerror(errno));
+        } else {
+            die("cannot create PAG: AFS support is not available");
+        }
+    }
 
     /* Now, the actual authentication part. */
     status = authenticate(ctx, &options);
